@@ -32,7 +32,7 @@ fn atan_poly_1<T>( y: T, x: T ) -> T
 fn atan_poly_2<T>( y: T, x: T ) -> T
     where T: mixed_num::MixedNum + mixed_num::MixedNumSigned
 {
-    let phi     = (x*y) / ( super::powi(y, 2) + T::mixed_from_num( 0.28125 )*x.mixed_powi(2) );
+    let phi     = (x*y) / ( y.mixed_powi( 2) + T::mixed_from_num( 0.28125 )*x.mixed_powi(2) );
     return phi;
 }
 
@@ -71,7 +71,7 @@ fn atan_poly_2<T>( y: T, x: T ) -> T
 /// ![Alt version](https://github.com/ErikBuer/Fixed-Trigonometry/blob/main/figures/atan2_comparisons.png?raw=true)
 /// 
 pub fn atan2<T>( y: T, x: T ) -> T
-    where T:  mixed_num::MixedNum + mixed_num::MixedNumSigned + cordic::CordicNumber
+    where T:  mixed_num::MixedNum + mixed_num::MixedNumSigned
 {
     // Precompute
     let y_abs = y.mixed_abs();
@@ -190,7 +190,7 @@ pub fn atan2<T>( y: T, x: T ) -> T
 /// ![Alt version](https://github.com/ErikBuer/Fixed-Trigonometry/blob/main/figures/atan_error_comparisons.png?raw=true)
 /// 
 pub fn atan<T>( x: T ) -> T
-    where T: mixed_num::MixedNum + mixed_num::MixedNumSigned + cordic::CordicNumber
+    where T: mixed_num::MixedNum + mixed_num::MixedNumSigned
 {
     return atan2(x,T::mixed_from_num(1));
 }
\ No newline at end of file
