@@ -1,5 +1,4 @@
-use super::*;
-
+use crate::atan;
 use num::complex::Complex;
 
 /// Cast cartesian complex fixed point number to polar form.
@@ -9,7 +8,7 @@ use num::complex::Complex;
 /// * `x` - The number transform.
 /// 
 pub fn to_polar<T>( x: Complex<T> ) -> Polar<T>
-    where T:  mixed_num::MixedNum + mixed_num::MixedNumSigned + fixed::traits::FixedSigned + cordic::CordicNumber
+    where T:  mixed_num::MixedNum + mixed_num::MixedNumSigned
 {
     let c_polar = Polar::<T>{
         r:     abs(x),
@@ -25,11 +24,11 @@ pub fn to_polar<T>( x: Complex<T> ) -> Polar<T>
 /// * `a` - The argument to apply the function to.
 /// 
 pub fn abs<T>( a: Complex<T> ) -> T
-where T: mixed_num::MixedNum + mixed_num::MixedNumSigned + fixed::traits::FixedSigned
+where T: mixed_num::MixedNum + mixed_num::MixedNumSigned
 {
     let r_sqr = super::powi( a.re, 2) + super::powi( a.im, 2);
     //return r_sqr.sqrt();
-    return sqrt::niirf(r_sqr, 2);
+    return mixed_num::trigonometry::sqrt::niirf(r_sqr, 2);
 }
 
 /// Polar complex nuber.
@@ -45,10 +44,12 @@ pub struct Polar<T> {
 /// * `a` - The number transform.
 /// 
 pub fn to_cartsian<T>( a: Polar<T> ) -> Complex<T>
-    where T: mixed_num::MixedNum + mixed_num::MixedNumSigned + cordic::CordicNumber
+    where T: mixed_num::MixedNum + mixed_num::MixedNumSigned + mixed_num::MixedTrigonometry
 {
-    let theta = wrap_phase(a.theta);
-    let (imag_s, real_s) = cordic::sin_cos( theta );
+    let theta = crate::wrap_phase(a.theta);
+    //let (imag_s, real_s) = cordic::sin_cos( theta );
+    let imag_s = theta.mixed_sin();
+    let real_s = theta.mixed_cos();
 
     let c_cartesian = Complex::<T>{
         re: a.r*real_s,
@@ -104,7 +105,7 @@ pub fn mul_polar<T>( a: Polar<T>, b: Polar<T> ) -> Polar<T>
 
 /// Multiply two polar numbers by transforming to polar, multiplying and transfomring back.
 pub fn mul_cartesian<T>( a: Complex<T>, b: Complex<T> ) -> Complex<T>
-    where T:  mixed_num::MixedNum + mixed_num::MixedNumSigned + fixed::traits::FixedSigned + cordic::CordicNumber
+    where T:  mixed_num::MixedNum + mixed_num::MixedNumSigned  + mixed_num::MixedTrigonometry
 {
     let a_pol = to_polar(a);
     let b_pol = to_polar(b);
@@ -140,7 +141,7 @@ pub fn powi<T>( base: num::complex::Complex<T>, power:usize ) -> num::complex::C
 {   
     // Calculate raised magnitude.
     let temp:T = super::powi( base.re, 2 ) + super::powi( base.im, 2 );
-    let mag:T  = super::powi( sqrt::niirf(temp, 2), power );
+    let mag:T  = super::powi( mixed_num::trigonometry::sqrt::niirf(temp, 2), power );
 
     let phi:T  = super::atan::atan2( base.im, base.re )*<T>::from_num(power);
 
