@@ -54,7 +54,7 @@
 /// 
 /// ![Alt version](https://github.com/ErikBuer/Fixed-Trigonometry/blob/main/figures/sqrt_error_comparison.png?raw=true)
 pub fn niirf<T>( x: T, iterations: usize ) -> T 
-    where T: fixed::traits::FixedSigned
+    where T: mixed_num::MixedNum + mixed_num::MixedNumSigned + fixed::traits::FixedSigned
 {
     if x == T::from_num(0)
     {
